
import { User } from 'lucide-react';
import { 
  Select, 
  SelectContent, 
  SelectItem, 
  SelectTrigger, 
  SelectValue 
} from "@/components/ui/select";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group";

interface PersonalInfoProps {
  formData: any;
  setFormData: (data: any) => void;
}

export const PersonalInfoSection = ({ formData, setFormData }: PersonalInfoProps) => {
  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setFormData(prev => ({ ...prev, [name]: value }));
  };

  const handleSelectChange = (name: string, value: string) => {
    setFormData(prev => ({ ...prev, [name]: value }));
  };

  return (
    <div className="glass-panel p-6 animate-fade-up">
      <div className="flex items-center gap-2 mb-6">
        <div className="w-8 h-8 rounded-full bg-brand-blue/10 flex items-center justify-center">
          <User className="w-4 h-4 text-brand-blue" />
        </div>
        <h3 className="font-semibold text-lg">Personal Information</h3>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
        <div className="space-y-2">
          <Label htmlFor="name">Full Name</Label>
          <Input 
            id="name" 
            name="name" 
            placeholder="John Doe" 
            className="input-field"
            value={formData.name || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="age">Age</Label>
          <Input 
            id="age" 
            name="age" 
            type="number" 
            placeholder="30" 
            className="input-field"
            value={formData.age || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="nidCardNumber">NID Card Number</Label>
          <Input 
            id="nidCardNumber" 
            name="nidCardNumber" 
            placeholder="1234567890" 
            className="input-field"
            value={formData.nidCardNumber || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="phoneNumber">Registered Phone Number</Label>
          <Input 
            id="phoneNumber" 
            name="phoneNumber" 
            placeholder="+880 1X XXXX XXXX" 
            className="input-field"
            value={formData.phoneNumber || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="gender">Gender</Label>
          <Select 
            value={formData.gender || ''} 
            onValueChange={(value) => handleSelectChange('gender', value)}
          >
            <SelectTrigger className="input-field">
              <SelectValue placeholder="Select gender" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="male">Male</SelectItem>
              <SelectItem value="female">Female</SelectItem>
              <SelectItem value="other">Other</SelectItem>
            </SelectContent>
          </Select>
        </div>

        <div className="space-y-2">
          <Label htmlFor="maritalStatus">Marital Status</Label>
          <Select 
            value={formData.maritalStatus || ''} 
            onValueChange={(value) => handleSelectChange('maritalStatus', value)}
          >
            <SelectTrigger className="input-field">
              <SelectValue placeholder="Select status" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="single">Single</SelectItem>
              <SelectItem value="married">Married</SelectItem>
              <SelectItem value="divorced">Divorced</SelectItem>
              <SelectItem value="widowed">Widowed</SelectItem>
            </SelectContent>
          </Select>
        </div>

        <div className="space-y-2">
          <Label htmlFor="education">Education Level</Label>
          <Select 
            value={formData.education || ''} 
            onValueChange={(value) => handleSelectChange('education', value)}
          >
            <SelectTrigger className="input-field">
              <SelectValue placeholder="Select education" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="high_school">High School</SelectItem>
              <SelectItem value="bachelors">Bachelor's Degree</SelectItem>
              <SelectItem value="masters">Master's Degree</SelectItem>
              <SelectItem value="phd">PhD</SelectItem>
              <SelectItem value="other">Other</SelectItem>
            </SelectContent>
          </Select>
        </div>

        <div className="space-y-2">
          <Label htmlFor="homeOwnership">Home Ownership</Label>
          <RadioGroup 
            defaultValue={formData.homeOwnership || 'rent'}
            onValueChange={(value) => handleSelectChange('homeOwnership', value)}
            className="flex gap-4"
          >
            <div className="flex items-center space-x-2">
              <RadioGroupItem value="own" id="own" />
              <Label htmlFor="own">Own</Label>
            </div>
            <div className="flex items-center space-x-2">
              <RadioGroupItem value="rent" id="rent" />
              <Label htmlFor="rent">Rent</Label>
            </div>
            <div className="flex items-center space-x-2">
              <RadioGroupItem value="mortgage" id="mortgage" />
              <Label htmlFor="mortgage">Mortgage</Label>
            </div>
          </RadioGroup>
        </div>
      </div>
    </div>
  );
};
